@@ -23,6 +23,8 @@ from typing import Tuple
 from typing import List
 from typing import Dict
 
+from edgebenchmark.settings import settings
+
 
 def send_model(
         protocol_version: Tuple[int, int, int],
@@ -33,34 +35,47 @@ def send_model(
         benchmark_type,
         benchmark_args: Dict,
 ):
-    from edgebenchmark.settings import settings
-
-    header = {
-        "token": token,
-        "protocol_version": json.dumps(protocol_version),
+    headers = {
+        "Token": token,
     }
 
-    body = {
+    data = {
+        "protocol_version": json.dumps(protocol_version),
         "time": time.time(),
         "model_hash": md5_hash(filepath=model_path),
         "model_name": model_path.name,
-        "devices": devices,
-        "features": features,
+        "devices": json.dumps(devices),
+        "features": json.dumps(features),
         "benchmark_type": benchmark_type.value,
-        "benchmark_args": benchmark_args,
+        "benchmark_args": json.dumps(benchmark_args),
     }
 
     files = {
-        "json": json.dumps({
-            "header": header,
-            "body": body,
-        }),
         "model_file": open(model_path, "rb"),
     }
 
     response = requests.put(
         settings._MODEL_ENDPOINT,
+        headers=headers,
         files=files,
+        data=data,
+    )
+
+    return response
+
+
+def get_devices(
+        protocol_version: Tuple[int, int, int],
+        token: str,
+):
+    data = {
+        "token": token,
+        "protocol_version": protocol_version,
+    }
+
+    response = requests.get(
+        settings._DEVICE_ENDPOINT,
+        json=data,
     )
 
     return response
@@ -80,7 +95,7 @@ def md5_hash(
 
     Args:
       data: Bytes to hash.
-      filepath: If filepath is given,  file is loaded and encoded with
+      filepath: If filepath is given, file is loaded and encoded with
       hash function.
       buffer_size: Size of a buffer that is used during data hashing.
     """
@@ -95,8 +110,6 @@ def md5_hash(
 
 
 def load_token_from_file():
-    from edgebenchmark.settings import settings
-
     settings._CONFIGURE_DIR.mkdir(parents=True, exist_ok=True)
 
     if settings._CREDENTIALS_FILE_PATH.exists():
@@ -111,4 +124,6 @@ def load_token_from_file():
                 print(f"Invalid format of credentials file located at {settings._CONFIGURE_DIR}", file=sys.stderr)
                 sys.exit(1)
     else:
-        raise FileNotFoundError
+        print(f"{settings._CREDENTIALS_FILE_PATH} file does not exist.\n" \
+              "Set token with commmand: edgebenchmark configure", file.sys.stderr)
+        sys.exit(1)
